import { Octokit } from '@octokit/rest';
export declare class MarkdownBatchParsingError extends Error {
    markdowns: string[];
    renderedMarkdowns: string[];
    rawRenderedMarkdown: string;
    separator: string;
    constructor(msg: string, markdowns: string[], renderedMarkdowns: string[], rawRenderedMarkdown: string, separator: string);
}
export declare type Options = {
    /**
     * The rendering mode.
     * @default "gfm"
     * */
    mode?: 'gfm' | 'markdown';
    /**
     * The repository context to use when creating references in gfm mode.
     * For example, setting context to octo-org/octo-repo will change the text
     * #42 into an HTML link to issue 42 in the octo-org/octo-repo repository.
     * */
    context?: string;
    /** The `Octokit` instance to use. */
    octokit?: Octokit;
};
/**
 * Batch-render markdowns via GitHub-API.
 *
 * Useful for mitigating GitHub's request rate-limit.
 * @param markdowns Array of markdown strings to render.
 * @param options Octokit options.
 * @returns Array of rendered markdown strings.
 */
export declare const ghMdBatchRender: (markdowns: string[], options?: Options) => Promise<string[]>;
